Command Reference
=================

Most of Buildcat's functionality can be accessed at the command line, using the following:

.. _buildcat:

buildcat
--------

.. argparse::
    :module: buildcat.cli
    :func: parser
    :prog: buildcat


